@@ -229,10 +229,8 @@ union EX_STYPE
 	Sflong_t	integer;
 	int		op;
 	char*		string;
-	void*		user;
-	struct Exbuf_s*	buffer;
 
-#line 236 "y.tab.h" /* yacc.c:1909  */
+#line 234 "y.tab.h" /* yacc.c:1909  */
 };
 
 typedef union EX_STYPE EX_STYPE;
