@@ -37,7 +37,6 @@ typedef enum {
     FORMAT_PNG_FIG,  FORMAT_GIF_FIG,  FORMAT_JPEG_FIG,
     FORMAT_PNG_VRML, FORMAT_GIF_VRML, FORMAT_JPEG_VRML,
     FORMAT_PS_PS, FORMAT_PSLIB_PS, 
-    FORMAT_PNG_VML, FORMAT_GIF_VML, FORMAT_JPEG_VML, 
     FORMAT_GIF_TK,
 } format_type;
 
@@ -119,17 +118,12 @@ static void core_loadimage_vrml(GVJ_t * job, usershape_t *us, boxf b, bool fille
     (void)b;
     (void)filled;
 
-    obj_state_t *obj;
-    node_t *n;
-
     assert(job);
-    obj = job->obj;
-    assert(obj);
+    assert(job->obj);
     assert(us);
     assert(us->name);
 
-    n = job->obj->u.n;
-    assert(n);
+    assert(job->obj->u.n);
 
     gvprintf(job, "Shape {\n");
     gvprintf(job, "  appearance Appearance {\n");
@@ -243,16 +237,6 @@ static void core_loadimage_pslib(GVJ_t * job, usershape_t *us, boxf b, bool fill
     }
 }
 
-static void core_loadimage_vml(GVJ_t * job, usershape_t *us, boxf b, bool filled)
-{
-    (void)filled;
-
-    int  graphHeight = (int)(job->bb.UR.y - job->bb.LL.y);
-    gvprintf (job, "<v:image src=\"%s\" style=\" position:absolute; width:%.2f; height:%.2f; left:%.2f ; top:%.2f\"",
-           us->name,  b.UR.x - b.LL.x, b.UR.y - b.LL.y, b.LL.x, graphHeight-b.UR.y);
-    gvputs(job, " />\n");
-}
-
 static void core_loadimage_tk(GVJ_t * job, usershape_t *us, boxf b, bool filled)
 {
     (void)filled;
@@ -300,10 +284,6 @@ static gvloadimage_engine_t engine_xdot = {
     core_loadimage_xdot
 };
 
-static gvloadimage_engine_t engine_vml = {
-    core_loadimage_vml
-};
-
 static gvloadimage_engine_t engine_tk = {
     core_loadimage_tk
 };
@@ -360,12 +340,6 @@ gvplugin_installed_t gvloadimage_core_types[] = {
 
     {FORMAT_SVG_SVG, "svg:svg", 1, &engine_svg, NULL},
 
-    {FORMAT_PNG_VML, "png:vml", 1, &engine_vml, NULL},
-    {FORMAT_GIF_VML, "gif:vml", 1, &engine_vml, NULL},
-    {FORMAT_JPEG_VML, "jpeg:vml", 1, &engine_vml, NULL},
-    {FORMAT_JPEG_VML, "jpe:vml", 1, &engine_vml, NULL},
-    {FORMAT_JPEG_VML, "jpg:vml", 1, &engine_vml, NULL},
-
     {FORMAT_GIF_TK, "gif:tk", 1, &engine_tk, NULL},
 
     {0, NULL, 0, NULL, NULL}
